<?php
/*
Plugin Name: Bing Custom Search for WordPress
Description: Bing Custom Search for WordPress
Version: 1.0.5
Author: SlipFire
Author URI: http://slipfire.com
Text Domain: wp-bing-search
Domain Path: /languages
License: GPLv2
*/

/*
  Copyright (c) 2012-2017 SlipFire Corp.
  All rights reserved.

  This software is distributed under the GNU General Public License, Version 2,
  June 1991. Copyright (C) 1989, 1991 Free Software Foundation, Inc., 51 Franklin
  St, Fifth Floor, Boston, MA 02110, USA

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

  *******************************************************************************
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *******************************************************************************
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


wp_bing_search::load();

class WP_Bing_Search {

	private static $custom_search_endpoint = 'https://api.cognitive.microsoft.com/bingcustomsearch/v5.0/search';

	public static $is_search = false;

	public static $settings = null;

	public static $api_results = null;

	public static $originalQuery = null;

	public static $alteredQuery = null;

	public static $estimated_matches = 0;

	public static $found_posts = 0;

	public static $posts_per_page = 10;

	public static $offset = 0;


	/**
	 * load
	 *
	 * Let's start Binging
	 */
	public static function load() {

		include( 'includes/wp_bing_search_settings.php' );

		if ( self::good_to_go() && self::load_theme_compatibility() ) {

			include( 'includes/wp_bing_search_theme_compatibility.php' );
		}

	}

	/**
	 * url
	 *
	 * Get full url path to this plugins directory
	 *
	 * @return string
	 */
	public static function url() {
		return plugins_url( '/', __FILE__ );
	}

	/**
	 * path
	 *
	 * Get filesystem directory path to this plugins directory
	 *
	 * @return string
	 */
	public static function path() {
		return plugin_dir_path( __FILE__ );
	}


	/**
	 * good_to_go
	 *
	 * If customconfig and api_key settings are filled in, then we're good to go!
	 *
	 * @return bool
	 */
	public static function good_to_go() {

		self::$settings = self::get_settings();

		if ( ! empty( self::$settings['customconfig'] ) && ! empty( self::$settings['api_key'] ) ) {

			return true;
		}

		return false;

	}

	public static function freemius() {

		global $wp_bing_search_freemius;

		if ( ! isset( $wp_bing_search_freemius ) ) {

			require_once dirname( __FILE__ ) . '/freemius/start.php';

			$wp_bing_search_freemius = fs_dynamic_init( array(
				'id'             => '1291',
				'slug'           => 'wp-bing-search',
				'type'           => 'plugin',
				'public_key'     => 'pk_20d787dc78b376ab17978fc9d9814',
				'is_premium'     => false,
				'has_addons'     => false,
				'has_paid_plans' => false,
				'menu'           => array(
					'slug'    => wp_bing_search,
					'account' => false,
					'contact' => false,
					'support' => false,
					'parent'  => array(
						'slug' => 'options-general.php',
					),
				),
			) );
		}

		return $wp_bing_search_freemius;
	}

	public static function load_theme_compatibility() {

		$load = true;

		/**
		 * Filters whether to load theme compatibility.
		 *
		 * You might want to stop theme compatibility if you use a shortcode or custom function instead.
		 *
		 * @param bool $load Whether theme compatibility should be loaded.
		 */
		return apply_filters( 'wp_bing_search_theme_compatibility', $load );
	}


	/**
	 * get_settings
	 *
	 * Get the plugin settings
	 *
	 * @return array
	 */
	public static function get_settings() {

		$setting = get_option( 'wp_bing_search' );

		$settings = array(
			'customconfig' => $setting['customconfig'],
			'mkt'          => $setting['mkt'],
			'count'        => $setting['count'],
			'safesearch'   => $setting['safesearch'],
			'api_key'      => $setting['api_key']
		);

		return $settings;
	}

	/**
	 * get_args
	 *
	 * replace settings with additional args
	 *
	 * @param array $additional_args
	 *
	 * @return array
	 */
	public static function get_args( $additional_args = array() ) {

		$args = wp_parse_args( $additional_args, self::$settings );

		self::$posts_per_page = $args['count'];
		self::$offset         = isset( $args['offset'] ) ? $args['offset'] : 0;

		return $args;

	}


	/**
	 * get_response
	 *
	 * Get the search response from Bing.
	 *
	 * @param null $args
	 *
	 * @return bool
	 */
	public static function get_response( $args = null ) {

		$endpoint = self::build_endpoint( $args );

		$options['headers']['Ocp-Apim-Subscription-Key'] = self::get_args()['api_key'];

		$response = wp_remote_get( $endpoint, $options );

		if ( is_wp_error( $response ) ) {

			error_log( 'WP_BING_SEARCH:ERROR - ' . print_r( $response, true ) );

			return false;

		}

		$body = json_decode( $response['body'] );

		if ( ! empty( $body->queryContext ) ) {

			self::$originalQuery = ! empty( $body->queryContext->originalQuery ) ? $body->queryContext->originalQuery : null;
			self::$alteredQuery  = ! empty( $body->queryContext->alteredQuery ) ? $body->queryContext->alteredQuery : null;

		}

		$webPages = $body->webPages;

		if ( $webPages ) {

			self::$estimated_matches = $webPages->totalEstimatedMatches;

			$results = $webPages->value;

			return $results;

		} else {

			return false;

		}

	}

	/**
	 * build_endpoint
	 *
	 * build the endpoint to ping Bing.
	 *
	 * @param $args
	 *
	 * @return bool|string
	 */
	public static function build_endpoint( $args ) {

		$endpoint = add_query_arg( array(
			'mkt'          => $args['mkt'],
			'count'        => $args['count'],
			'offset'       => $args['offset'],
			'safesearch'   => $args['safesearch'],
			'customconfig' => $args['customconfig'],
			'q'            => $_GET['s']
		), self::$custom_search_endpoint );

		return $endpoint;

	}

	/**
	 * get_matches
	 *
	 * Get estimated search results number
	 *
	 * @return int
	 */
	public static function get_matches() {

		return intval( self::$estimated_matches );

	}


}


wp_bing_search::freemius();

do_action( 'wp_bing_search_freemius_loaded' );